baseStore.BdbStore

|  | ## Cheshire3 Object Model: Class BdbStore

Module baseStore :: Class BdbStore

## Class BdbStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                  SimpleStore --+
                                |
                               BdbStore

Known Subclasses:
  documentStore.BdbDocumentStore, recordStore.BdbRecordStore, queryStore.SimpleQueryStore, resultSetStore.BdbResultSetStore

Berkeley DB based storage
Instance Methods

__iter__(self)
_closeContainer(self, session)
_initialise(self, dbp)
_openContainer(self, session)
_verifyDatabase(self, dbp)
_verifyDatabases(self, session)
begin_storing(self, session)
clean(self, session)
commit_storing(self, session)
delete_item(self, session, id)
fetch_checksum(self, session, id)
fetch_data(self, session, id)
fetch_idList(self, session, numReq=-1, start="")
fetch_size(self, session, id)
generate_id(self, session)
get_dbsize(self, session)
store_checkSum(self, session, id, digest)
store_data(self, session, id, data, size=0)
verify_checkSum(self, session, id, data, store=1)
Inherited from `SimpleStore`: `__init__` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

cxn |
digestCxn |
digestForId |
Inherited from `SimpleStore`: `currentId`, `idNormalizer` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __iter__(self) | source code

### _closeContainer(self, session) | source code

### _initialise(self, dbp) | source code

### _openContainer(self, session) | source code

### _verifyDatabase(self, dbp) | source code

### _verifyDatabases(self, session) | source code
Overrides: SimpleStore._verifyDatabases

### begin_storing(self, session) | source code

### clean(self, session) | source code

### commit_storing(self, session) | source code

### delete_item(self, session, id) | source code

### fetch_checksum(self, session, id) | source code

### fetch_data(self, session, id) | source code

### fetch_idList(self, session, numReq=-1, start="") | source code

### fetch_size(self, session, id) | source code

### generate_id(self, session) | source code

### get_dbsize(self, session) | source code

### store_checkSum(self, session, id, digest) | source code

### store_data(self, session, id, data, size=0) | source code

### verify_checkSum(self, session, id, data, store=1) | source code

Class Variable Details

    ### cxn Value:
        None

    ### digestCxn Value:
        None

    ### digestForId Value:
        0